@@ -94,6 +94,7 @@ static void checkZone           _((diDiskInfo_t *, zoneInfo_t *, unsigned int));
 static void checkIgnoreList     _((diDiskInfo_t *, iList_t *));
 static void checkIncludeList    _((diDiskInfo_t *, iList_t *));
 static int  isIgnoreFSType      _((char *));
+static int  isIgnoreSpecial     _((char *));
 #if _lib_realpath && _define_S_ISLNK && _lib_lstat
 static int  checkForUUID        _((char *));
 #endif
@@ -365,17 +366,14 @@ checkFileInfo (diData, optidx, argc, argv)
             inpool = FALSE;
           }
 
-          if (poolmain)
-          {
+          if (poolmain) {
             saveIdx = j;
           }
 
-          if (found && inpool)
-          {
+          if (found && inpool) {
             dinfo = &(diskInfo [diskInfo [j].sortIndex[DI_TOT_SORT_IDX]]);
             dinfo->printFlag = DI_PRNT_SKIP;
-            if (debug > 2)
-            {
+            if (debug > 2) {
               printf ("  inpool B: also process %s %s\n",
                       dinfo->special, dinfo->name);
             }
@@ -396,22 +394,22 @@ checkFileInfo (diData, optidx, argc, argv)
             }
             if (foundnew == 3) {
               dinfo->printFlag = DI_PRNT_FORCE;
+              found = TRUE;
             }
 
-            found = TRUE;
-            if (debug > 2)
-            {
+            if (debug > 2) {
               printf ("file %s specified: found device %ld : %d (%s %s)\n",
                       argv[i], dinfo->st_dev, foundnew,
                       dinfo->special, dinfo->name);
             }
-            if (inpool)
-            {
+
+            if (inpool) {
               int   k;
-              for (k = saveIdx; k < j; ++k)
-              {
+              for (k = saveIdx; k < j; ++k) {
                 dinfo = &(diskInfo [diskInfo [k].sortIndex[DI_TOT_SORT_IDX]]);
-                dinfo->printFlag = DI_PRNT_SKIP;
+                if (dinfo->printFlag != DI_PRNT_FORCE) {
+                  dinfo->printFlag = DI_PRNT_SKIP;
+                }
                 if (debug > 2)
                 {
                   printf ("  inpool A: also process %s %s\n",
@@ -686,7 +684,14 @@ checkDiskInfo (diData, hasLoop)
             dinfo->printFlag = DI_PRNT_IGNORE;
             dinfo->doPrint = (char) diopts->displayAll;
             if (debug > 2) {
-              printf ("chk: ignore: rootfs/procfs/devfs/devtmpfs: %s\n", dinfo->name);
+              printf ("chk: ignore-fs: %s\n", dinfo->name);
+            }
+          }
+          if (isIgnoreSpecial (dinfo->special)) {
+            dinfo->printFlag = DI_PRNT_IGNORE;
+            dinfo->doPrint = (char) diopts->displayAll;
+            if (debug > 2) {
+              printf ("chk: ignore-special: %s\n", dinfo->special);
             }
           }
 
@@ -1267,6 +1272,27 @@ initZones (diData)
 #endif
 }
 
+static int
+#if _proto_stdc
+isIgnoreSpecial (char *special)
+#else
+isIgnoreSpecial (special)
+  char      *special;
+#endif
+{
+  static char   *appletimemachine = "com.apple.TimeMachine.";
+
+  /* solaris: swap */
+  /* linux: cgroup, tmpfs */
+  if (strncmp (special, appletimemachine, strlen(appletimemachine)) == 0 ||
+      strcmp (special, "tmpfs") == 0 ||
+      strcmp (special, "cgroup") == 0 ||
+      strcmp (special, "swap") == 0) {
+    return TRUE;
+  }
+  return FALSE;
+}
+
 static int
 #if _proto_stdc
 isIgnoreFSType (char *fstype)
